import { ApiProperty } from '@nestjs/swagger';
import {
  Column,
  Entity,
  JoinColumn,
  ManyToOne,
  OneToMany,
  PrimaryGeneratedColumn,
} from 'typeorm';
import { Zone } from './zone.entity';
import { Category } from './category.entity';

@Entity('groups')
export class Group {
  // ----------------------------------------
  @ApiProperty({
    type: Number,
    name: 'id',
    description: 'id of group, auto-incremented',
    required: true,
  })
  @PrimaryGeneratedColumn('increment')
  id: number;

  // ----------------------------------------
  @ApiProperty({
    type: String,
    name: 'name',
    description: 'Group name',
    required: true,
  })
  @Column({
    type: 'varchar',
  })
  name: string;

  // ----------------------------------------
  @ApiProperty({
    type: Number,
    name: 'displayOrder',
    description: 'Display order',
    required: false,
  })
  @Column({
    type: 'tinyint',
    default: 0,
  })
  displayOrder: number;

  // ----------------------------------------
  @ApiProperty({
    name: 'zone',
    description: 'Parent node: zone',
    type: () => Zone,
  })
  // @ApiPropertyOptional()
  @ManyToOne(() => Zone, (zone) => zone.groups, {
    nullable: false,
    eager: true,
  })
  @JoinColumn({ name: 'xref_zone_id' })
  zone: Zone;

  // ----------------------------------------
  @ApiProperty({
    name: 'categories',
    description: 'Children: categories',
    type: () => [Category],
  })
  // @ApiPropertyOptional()
  @OneToMany(() => Category, (category) => category.group)
  categories: Category[];
}
